# gobbler
[![Travis CI](https://travis-ci.com/RaySSharma/gobble.svg?branch=master)](https://travis-ci.org/RaySSharma/gobble) 
[![Wheel](https://img.shields.io/pypi/wheel/gobble.svg)](https://pypi.org/project/gobbler/)
[![codecov](https://codecov.io/gh/RaySSharma/gobble/branch/master/graph/badge.svg)](https://codecov.io/gh/RaySSharma/gobble)



A turkey-themed image catalog featuring over 99 hand-picked images to boost the holiday mood.

## Usage

### Python
```python
from gobble import gobble

gobble.gobble()
gobble.gobble(99)
```
### Command line
```
usage: gobble [-h] [-n NUM]

A turkey-themed image catalog featuring over 99 hand-picked images to boost
the holiday mood.

optional arguments:
-h, --help         show this help message and exit
-n NUM, --num NUM  Specify image number
```

## License

MIT © [Ray Sharma](https://rayssharma.com)
